#include <iostream>
#include <vector>
#include <algorithm>

using namespace std;

struct d_tree {
    struct node {
        node *l = nullptr;
        node *r = nullptr;
        int sz = 0;
        int x, y;

        node() {}

        node(int _x) {
            x = _x;
            y = rand();
            sz = 1;
        }
    };

    inline int s(node *x) {
        if (!x) {
            return 0;
        }
        return x->sz;
    }

    inline void upd(node *x) {
        if (!x) return;
        x->sz = s(x->l) + s(x->r) + 1;
    }

    node *merge(node *l, node *r) {
        if (!l) return r;
        if (!r) return l;
        if (l->y > r->y) {
            l->r = merge(l->r, r);
            upd(l);
            return l;
        } else {
            r->l = merge(l, r->l);
            upd(r);
            return r;
        }
    }

    typedef pair<node *, node *> Pair;

    Pair split(node *x, int k) {
        if (!x) return {nullptr, nullptr};
        if (x->x <= k) {
            Pair q = split(x->r, k);
            x->r = q.first;
            upd(x);
            return {x, q.second};
        } else {
            Pair q = split(x->l, k);
            x->l = q.second;
            upd(x);
            return {q.first, x};
        }
    }

    node* root = nullptr;

    void insert(int x) {
        Pair q = split(root, x);
        node* t = new node(x);
        root = merge(q.first, merge(t, q.second));
    }

    int get(int x) {
        Pair q = split(root, x);
        int ans = s(q.first);
        root = merge(q.first, q.second);
        return ans;
    }

    int get1(int x) {
        Pair q = split(root, x);
        int ans = s(q.second);
        root = merge(q.first, q.second);
        return ans;
    }

    void del(int x) {
        Pair q = split(root, x);
        Pair q1 = split(q.first, x - 1);
        root = merge(q1.first, q.second);
    }
};

struct tree {
    vector<d_tree> tr;

    void init(int n) {
        tr.resize(n * 4);
    }

    void build(int i, int l, int r, vector<int> &a) {
        for (int j = l; j < r; ++j) {
            tr[i].insert(a[j]);
        }
        if (l + 1 == r) {
            return;
        }
        int m = (l + r) / 2;
        build(i * 2 + 1, l, m, a);
        build(i * 2 + 2, m, r, a);
    }

    int get(int i, int l, int r, int ql, int qr, int x) {
        if (qr <= l || r <= ql) {
            return 0;
        }
        if (ql <= l && r <= qr) {
            return tr[i].get(x);
        }
        int m = (l + r) / 2;
        return get(i * 2 + 1, l, m, ql, qr, x) + get(i * 2 + 2, m, r, ql, qr, x);
    }

    int get1(int i, int l, int r, int ql, int qr, int x) {
        if (qr <= l || r <= ql) {
            return 0;
        }
        if (ql <= l && r <= qr) {
            return tr[i].get1(x);
        }
        int m = (l + r) / 2;
        return get1(i * 2 + 1, l, m, ql, qr, x) + get1(i * 2 + 2, m, r, ql, qr, x);
    }

    void del(int i, int l, int r, int qi, int val) {
        if (r <= qi || qi < l) {
            return;
        }
        tr[i].del(val);
        if (l + 1 == r) {
            return;
        }
        int m = (l + r) / 2;
        del(i * 2 + 1, l, m, qi, val);
        del(i * 2 + 2, m, r, qi, val);
    }
};

int main() {
    int n;
    cin >> n;
    vector<int> a(n);
    for (int &i : a) {
        cin >> i;
    }
    int m = n - 2;
    vector<int> ord(m);
    for (int &i : ord) {
        cin >> i;
    }
    tree st;
    st.init(n);
    st.build(0, 0, n, a);
    int ans = 0;
    for(int i = 0; i < n; ++i) {
        int k = st.get1(0, 0, n, 0, i, a[i]);
        ans += k;
    }
    vector<int> pos(n + 1);
    for(int i = 0; i < n; ++i) {
        pos[a[i]] = i;
    }
    cout << ans << '\n';
    for (int j = 0; j < m; ++j) {
        int i = pos[ord[j]];
        ans -= st.get1(0, 0, n, 0, i, a[i]);
        cerr << ans << '\n';
        ans -= st.get(0, 0, n, i + 1, n, a[i]);
        cerr << ans << '\n';
        st.del(0, 0, n, i, a[i]);
        cout << ans << '\n';
    }

    return 0;
}