#include <iostream>
#include <vector>
#include <algorithm>
#include <random>

using namespace std;

mt19937 rnd;

struct d_tree {
    vector<int> l;
    vector<int> r;
    vector<int> sz;
    vector<int> x;
    vector<int> y;

    int cnt = 0;

    int new_node(int X) {
        sz.push_back(1);
        l.push_back(-1);
        r.push_back(-1);
        x.push_back(X);
        y.push_back(rnd());
        ++cnt;
        return cnt - 1;
    }

    inline int s(int i) {
        if (i == -1) {
            return 0;
        }
        return sz[i];
    }

    inline void upd(int i) {
        if (i == -1) return;
        sz[i] = s(l[i]) + s(r[i]) + 1;
    }

    int merge(int a, int b) {
        if (a == -1) return b;
        if (b == -1) return a;
        if (y[a] > y[b]) {
            r[a] = merge(r[a], b);
            upd(a);
            return a;
        } else {
            l[b] = merge(a, l[b]);
            upd(b);
            return b;
        }
    }

    typedef pair<int, int> Pair;

    Pair split(int v, int k) {
        if (v == -1) return {-1, -1};
        if (x[v] <= k) {
            Pair q = split(r[v], k);
            r[v] = q.first;
            upd(v);
            return {v, q.second};
        } else {
            Pair q = split(l[v], k);
            l[v] = q.second;
            upd(v);
            return {q.first, v};
        }
    }

    int root = -1;

    void insert(int x) {
        Pair q = split(root, x);
       int t = new_node(x);
        root = merge(q.first, merge(t, q.second));
    }

    int get(int x) {
        Pair q = split(root, x);
        int ans = s(q.first);
        root = merge(q.first, q.second);
        return ans;
    }

    int get1(int x) {
        Pair q = split(root, x);
        int ans = s(q.second);
        root = merge(q.first, q.second);
        return ans;
    }

    void del(int x) {
        Pair q = split(root, x);
        Pair q1 = split(q.first, x - 1);
        root = merge(q1.first, q.second);
    }
};

struct tree {
    vector<d_tree> tr;

    void init(int n) {
        tr.resize(n * 4);
    }

    void build(int i, int l, int r, vector<int> &a) {
        for (int j = l; j < r; ++j) {
            tr[i].insert(a[j]);
        }
        if (l + 1 == r) {
            return;
        }
        int m = (l + r) / 2;
        build(i * 2 + 1, l, m, a);
        build(i * 2 + 2, m, r, a);
    }

    int get(int i, int l, int r, int ql, int qr, int x) {
        if (qr <= l || r <= ql) {
            return 0;
        }
        if (ql <= l && r <= qr) {
            return tr[i].get(x);
        }
        int m = (l + r) / 2;
        return get(i * 2 + 1, l, m, ql, qr, x) + get(i * 2 + 2, m, r, ql, qr, x);
    }

    int get1(int i, int l, int r, int ql, int qr, int x) {
        if (qr <= l || r <= ql) {
            return 0;
        }
        if (ql <= l && r <= qr) {
            return tr[i].get1(x);
        }
        int m = (l + r) / 2;
        return get1(i * 2 + 1, l, m, ql, qr, x) + get1(i * 2 + 2, m, r, ql, qr, x);
    }

    void del(int i, int l, int r, int qi, int val) {
        if (r <= qi || qi < l) {
            return;
        }
        tr[i].del(val);
        if (l + 1 == r) {
            return;
        }
        int m = (l + r) / 2;
        del(i * 2 + 1, l, m, qi, val);
        del(i * 2 + 2, m, r, qi, val);
    }
};

int main() {
    ios_base::sync_with_stdio(false);
    cin.tie(0);
    cout.tie(0);
    int n;
    cin >> n;
    vector<int> a(n);
    for (int &i : a) {
        cin >> i;
    }
    int m = n - 2;
    vector<int> ord(m);
    for (int &i : ord) {
        cin >> i;
    }
    tree st;
    st.init(n);
    st.build(0, 0, n, a);
    int ans = 0;
    for(int i = 0; i < n; ++i) {
        int k = st.get1(0, 0, n, 0, i, a[i]);
        ans += k;
    }
    vector<int> pos(n + 1);
    for(int i = 0; i < n; ++i) {
        pos[a[i]] = i;
    }
    cout << ans << ' ';
    for (int j = 0; j < m; ++j) {
        int i = pos[ord[j]];
        ans -= st.get1(0, 0, n, 0, i, a[i]);
        ans -= st.get(0, 0, n, i + 1, n, a[i]);
        st.del(0, 0, n, i, a[i]);
        cout << ans << ' ';
    }

    return 0;
}