#include <iostream>
#include <vector>
#include <algorithm>
#include <random>

using namespace std;

#pragma GCC target("avx,avx2,sse,sse2,sse3,sse4")
#pragma GCC optimize("unroll-loops")
#pragma GCC optimize("O3")

mt19937 rnd;

struct d_tree {
    struct node {
        node *l = nullptr;
        node *r = nullptr;
        int sz = 0;
        int x, y;

        node() {}

        node(int _x) {
            x = _x;
            y = rnd();
            sz = 1;
        }
    };

    inline int s(node *x) {
        if (!x) {
            return 0;
        }
        return x->sz;
    }

    inline void upd(node *x) {
        if (!x) return;
        x->sz = s(x->l) + s(x->r) + 1;
    }

    node *merge(node *l, node *r) {
        if (!l) return r;
        if (!r) return l;
        if (l->y > r->y) {
            l->r = merge(l->r, r);
            upd(l);
            return l;
        } else {
            r->l = merge(l, r->l);
            upd(r);
            return r;
        }
    }

    typedef pair<node *, node *> Pair;

    Pair split(node *x, int k) {
        if (!x) return {nullptr, nullptr};
        if (x->x <= k) {
            Pair q = split(x->r, k);
            x->r = q.first;
            upd(x);
            return {x, q.second};
        } else {
            Pair q = split(x->l, k);
            x->l = q.second;
            upd(x);
            return {q.first, x};
        }
    }

    node *root = nullptr;

    void insert(int x) {
        Pair q = split(root, x);
        node *t = new node(x);
        root = merge(q.first, merge(t, q.second));
    }

    int get(int x) {
        Pair q = split(root, x);
        int ans = s(q.first);
        root = merge(q.first, q.second);
        return ans;
    }

    int get1(int x) {
        Pair q = split(root, x);
        int ans = s(q.second);
        root = merge(q.first, q.second);
        return ans;
    }

    void del(int x) {
        Pair q = split(root, x);
        Pair q1 = split(q.first, x - 1);
        root = merge(q1.first, q.second);
    }
};

const int n = (1 << 17);

d_tree tr[n * 2];

void build(int i, int l, int r, vector<int> &a) {
    for (int j = l; j < min((int) a.size(), r); ++j) {
        tr[i].insert(a[j]);
    }
    if (l + 1 == r) {
        return;
    }
    int m = (l + r) / 2;
    build(i * 2, l, m, a);
    build(i * 2 + 1, m, r, a);
}

int get(int l, int r, int x) {
    l += n;
    r += n;
    int ans = 0;
    while (l < r) {
        if (l & 1) {
            ans += tr[l].get(x);
            ++l;
        }
        if (r & 1) {
            --r;
            ans += tr[r].get(x);
        }
        r /= 2;
        l /= 2;
    }
    return ans;
}

int get1(int l, int r, int x) {
    l += n;
    r += n;
    int ans = 0;
    while (l < r) {
        if (l & 1) {
            ans += tr[l].get1(x);
            ++l;
        }
        if (r & 1) {
            --r;
            ans += tr[r].get1(x);
        }
        r /= 2;
        l /= 2;
    }
    return ans;
}

void del(int i, int l, int r, int qi, int val) {
    if (r <= qi || qi < l) {
        return;
    }
    tr[i].del(val);
    if (l + 1 == r) {
        return;
    }
    int m = (l + r) / 2;
    del(i * 2, l, m, qi, val);
    del(i * 2 + 1, m, r, qi, val);
}

int main() {
    ios_base::sync_with_stdio(false);
    cin.tie(0);
    cout.tie(0);
    int N = n;
    int n;
    cin >> n;
    vector<int> a(n);
    for (int &i : a) {
        cin >> i;
    }
    int m = n - 2;
    vector<int> ord(m);
    for (int &i : ord) {
        cin >> i;
    }
    build(1, 0, N, a);
    int ans = 0;
    for (int i = 0; i < n; ++i) {
        int k = get1(0, i, a[i]);
        ans += k;
    }
    vector<int> pos(n + 1);
    for (int i = 0; i < n; ++i) {
        pos[a[i]] = i;
    }
    cout << ans << ' ';
    for (int j = 0; j < m; ++j) {
        int i = pos[ord[j]];
        ans -= get1(0, i, a[i]);
        ans -= get(i + 1, n, a[i]);
        del(1, 0, N, i, a[i]);
        cout << ans << ' ';
    }

    return 0;
}