#include <bits/stdc++.h>
using namespace std;
typedef long long ll;

struct treap{
    void insert(int key){
        node* nd = new node(key);
        pair<node*, node*> p = split(root, key);
        root = merge(merge(p.first, nd), p.second);
    }

    int lesser(int key){
        pair<node*, node*> p = split(root, key);
        int ans = p.first == nullptr ? 0 : p.first->size;
        root = merge(p.first, p.second);
        return ans;
    }

    void erase(int key){
        pair<node*, node*> p1 = split(root, key);
        pair<node*, node*> p2 = split(p1.second, key + 1);
        root = merge(p1.first, p2.second);
    }

    void get_all_elements(vector<int>& arr){
        dfs(arr, root);
    }

    private:
        struct node{
            node* l, *r;
            int key;
            int prior;
            int size;

            node(int key_){
                l = r = nullptr;
                key = key_;
                prior = rand();
                size = 1;
            }
        };

        node* root;

        void update(node* nd){
            nd->size = 1;
            if(nd->l != nullptr){
                nd->size += nd->l->size;
            }
            if(nd->r != nullptr){
                nd->size += nd->r->size;
            }
        }

        node* merge(node* l, node* r){
            if(l == nullptr){
                return r;
            }
            if(r == nullptr){
                return l;
            }
            if(l->prior > r->prior){
                l->r = merge(l->r, r);
                update(l);
                return l;
            }
            r->l = merge(l, r->l);
            update(r);
            return r;
        }

        pair<node*, node*> split(node* rt, int x){
            if(rt == nullptr){
                return {nullptr, nullptr};
            }
            if(rt->key == x){
                node* l = rt->l;
                rt->l = nullptr;
                update(rt);
                return {l, rt};
            }
            if(rt->key > x){
                pair<node*, node*> p = split(rt->l, x);
                rt->l = p.second;
                update(rt);
                return {p.first, rt};
            }
            pair<node*, node*> p = split(rt->r, x);
            rt->r = p.first;
            update(rt);
            return {rt, p.second};
        }

        void dfs(vector<int>& arr, node* nd){
            if(nd == nullptr){
                return;
            }
            arr.push_back(nd->key);
            dfs(arr, nd->l);
            dfs(arr, nd->r);
        }
};


struct segment_tree{
    void insert_data(vector<int> arr){
        data = arr;
        size = 1;
        while(size < arr.size()){
            size *= 2;
        }
        tree.resize(2 * size - 1);
        for(int i = 0; i < arr.size(); i++){
            tree[size - 1 + i].insert(arr[i]);
        }
        for(int i = size - 2; i >= 0; i--){
            vector<int> arr1;
            tree[i * 2 + 1].get_all_elements(arr1);
            vector<int> arr2;
            tree[i * 2 + 2].get_all_elements(arr2);
            for(auto& x : arr1){
                tree[i].insert(x);
            }
            for(auto& x : arr2){
                tree[i].insert(x);
            }
        }
    }

    void erase(int i){
        erase(0, 0, size, i);
    }

    int lesser(int l, int r, int x){
        return lesser(0, 0, size, l, r, x);
    }

    private:
        vector<treap> tree;
        int size;
        vector<int> data;

        void erase(int i_nd, int l_nd, int r_nd, int i){
            tree[i_nd].erase(data[i]);
            if(r_nd - l_nd == 1){
                return;
            }
            int m_nd = (l_nd + r_nd) / 2;
            if(i < m_nd){
                erase(i_nd * 2 + 1, l_nd, m_nd, i);
            } else {
                erase(i_nd * 2 + 2, m_nd, r_nd, i);
            }
        }

        int lesser(int i_nd, int l_nd, int r_nd, int l, int r, int x){
            if(l_nd >= l && r_nd <= r){
                return tree[i_nd].lesser(x);
            } else if(r_nd <= l || l_nd >= r){
                return 0;
            } else {
                int m_nd = (l_nd + r_nd) / 2;
                return lesser(i_nd * 2 + 1, l_nd, m_nd, l, r, x) + lesser(i_nd * 2 + 2, m_nd, r_nd, l, r, x);
            }
        }
};

signed main(){
    ios_base::sync_with_stdio(false), cin.tie(nullptr), cout.tie(nullptr);
    int n;
    cin >> n;
    vector<int> a(n);
    vector<int> ra(n);
    segment_tree tr;
    segment_tree rtr;
    for(int i = 0; i < n; i++){
        cin >> a[i];
        ra[i] = -a[i];
    }
    tr.insert_data(a);
    rtr.insert_data(ra);
    vector<int> qst(n - 2);
    for(int i = 0; i < n - 2; i++){
        cin >> qst[i];
    }
    vector<int> pos(n + 1);
    ll ans = 0;
    for(int i = 0; i < n; i++){
        ans += tr.lesser(i, n, a[i]);
        pos[a[i]] = i;
    }
    cout << ans << ' ';
    for(int t = 0; t < n - 2; t++){
        int i = pos[qst[t]];
        tr.erase(i);
        rtr.erase(i);
        ans -= tr.lesser(i, n, a[i]);
        ans -= rtr.lesser(0, i, ra[i]);
        cout << ans << ' ';
    }
}
