//#define _GLIBCXX_DEBUG
#include <bits/stdc++.h>

using std::cin;
using std::cout;
using std::cerr;
using std::vector;
using std::string;
using std::pair;

using ll = long long;
using ld = long double;

const int INF = 1e9;

int getRand() {
	return (rand() << 15) + rand();
}

struct Node {
	int x, y = getRand();
	int size = 1;
	Node *l, *r;
	Node (int x) : x(x) {};
};

void print (Node* root) {
	if (root == nullptr)
		return;
	cout << root->x;
	cout << 'l';
	print(root->l);
	cout << 'r';
	print(root->r);
	cout << std::endl;
}

int getSize (Node *root) {
	return (root == nullptr ? 0 : root->size);
}

void update (Node *root) {
	root->size = getSize(root->l) + getSize(root->r) + 1;
}

pair<Node*, Node*> split (Node* root, int k) {
	if (root == nullptr)
		return {nullptr, nullptr};
	Node *l, *r;
	if (root->x < k) {
		std::tie(l, r) = split(root->r, k);
		root->r = l;
		update(root);
		return {root, r};
	} else {
		std::tie(l, r) = split(root->l, k);
		root->l = r;
		update(root);
		return {l, root};
	}
}

Node* merge (Node* l, Node* r) {
	if (l == nullptr)
		return r;
	if (r == nullptr)
		return l;
	if (l->y > r->y) {
		l->r = merge(l->r, r);
		update(l);
		return l;
	} else {
		r->l = merge(l, r->l);
		update(r);
		return r;
	}
}

Node* insert (Node* root, Node* v) {
	if (root == nullptr)
		return v;

	if (root->y < v->y) {
		Node *l, *r;
		std::tie(l, r) = split(root, v->x);
		v->l = l, v->r = r;
		update(v);
		return v;
	}
	if (root->x < v->x) {
		root->r = insert(root->r, v);
		update(root);
		return root;
	} else {
		root->l = insert(root->l, v);
		update(root);
		return root;
	}
}

Node* erase (Node* root, int x) {
	if (root == nullptr)
		return root;
	if (root->x == x)
		return merge(root->l, root->r);
	if (root->x < x) {
		root->r = erase(root->r, x);
		update(root);
		return root;
	} else {
		root->l = erase(root->l, x);
		update(root);
		return root;
	}
}

int get (Node* root, int x) {
	if (root == nullptr)
		return 0;
	if (root->x < x)
		return get(root->r, x) + getSize(root->l) + 1;
	else
		return get(root->l, x);
}



vector<int> deleted;

void set (int i) {
	++i;
	for (; i < deleted.size(); i += i & (-i))
		deleted[i] += 1;
}

int get (int i) {
	int ans = 0;
	for (; i > 0; i -= i & (-i))
		ans += deleted[i];
	return ans;
}

int get (int l, int r) {
	return get(r) - get(l);
}

vector<Node*> tr;
vector<int> d;

void build (int v, int vl, int vr) {
	if (vr - vl == 1) {
		tr[v] = new Node(d[vl]);
		return;
	}
	int m = (vl + vr) / 2;
	build (v * 2 + 1, vl, m);
	build (v * 2 + 2, m, vr);
	for (int i = vl; i < vr; ++i)
		tr[v] = insert(tr[v], new Node(d[i]));
}

int count_lt (int v, int vl, int vr, int l, int r, int x) {
	if (r <= vl || vr <= l)
		return 0;
	if (l <= vl && vr <= r) {
		return get(tr[v], x);
	}
	int m = (vl + vr) / 2;
	return count_lt(v * 2 + 1, vl, m, l, r, x) + count_lt(v * 2 + 2, m, vr, l, r, x);
}

int count_gt (int v, int vl, int vr, int l, int r, int x) {
	if (r <= vl || vr <= l)
		return 0;
	if (l <= vl && vr <= r) {
		return vr - vl - get(tr[v], x);
	}
	int m = (vl + vr) / 2;
	return count_gt(v * 2 + 1, vl, m, l, r, x) + count_gt(v * 2 + 2, m, vr, l, r, x);
}

void erase (int v, int vl, int vr, int l, int r, int x) {
	if (r <= vl || vr <= l)
		return;
	if (vr - vl == 1) {
		tr[v] = erase(tr[v], x);
		return;
	}
	tr[v] = erase(tr[v], x);
	//assert(getSize(tr[v]) == vr - vl);
	int m = (vl + vr) / 2;
	erase(v * 2 + 1, vl, m, l, r, x);
	erase(v * 2 + 2, m, vr, l, r, x);
}

int main() {
	std::ios_base::sync_with_stdio(false);
	cin.tie(0), cout.tie(0);

	int n;
	cin >> n;

	d.resize(n);
	deleted.resize(n + 1);
	tr.resize(4 * n);
	for (int &i : d)
		cin >> i;

	vector<int> pos(n);
	for (int i = 0; i < n; ++i) {
		pos[d[i] - 1] = i;
	}

	build(0, 0, n);

	ll sum = 0;

	for (int i = 0; i < n; ++i)
		sum += count_gt(0, 0, n, 0, i, d[i]);
	cout << sum << ' ';

	for (int i = 0; i < n - 2; ++i) {
		int a;
		cin >> a;
		--a;
		int ind = pos[a];
		sum -= count_gt(0, 0, n, 0, ind, d[ind]) - get(ind);
		sum -= count_lt(0, 0, n, ind, n, d[ind]);
		erase(0, 0, n, ind, ind + 1, a + 1);
		d[ind] = -1;
		set(ind);
		cout << sum << ' ';
	}


	return 0;
}