﻿#include <iostream>
#include <vector>
#include <numeric>
#include <algorithm>



class BIT {
private:
	int size, *data;

public:

	BIT() : size(0), data(nullptr) {

	}

	BIT(int n, int fl = 1) : size(n), data(new int[n]) {
		for (int i = 0; i < n; i++) {
			data[i] = (i - ((i & (i + 1)) - 1)) * fl;
		}
	}


	void update(int i, int dlt) {
		for (; i < size; i |= i + 1) {
			data[i] += dlt;
		}
	}

	int get(int i) {
		int res = 0;
		for (; i >= 0; i = (i & (i + 1)) - 1) {
			res += data[i];
		}
		return res;
	}
};



class MST {
private:
	int size, *sizes, **data;
	BIT *bt;


	int gt(int i, int val) {
		int p = std::upper_bound(data[i], data[i] + sizes[i], val) - data[i];
		return bt[i].get(sizes[i] - 1) - bt[i].get(p - 1);
	}
	
	int ls(int i, int val) {
		int p = std::lower_bound(data[i], data[i] + sizes[i], val) - data[i];
		return bt[i].get(p - 1);
	}


public:

	MST(int n, int *base) {
		for (size = 1; size < n; size *= 2) {
			;
		}
		sizes = new int[size * 2];
		data = new int *[size * 2];
		bt = new BIT[size * 2];
		std::fill(sizes + size, sizes + size + n, 1);
		std::fill(sizes + size + n, sizes + size * 2, 0);
		for (int i = 0; i < n; i++) {
			data[size + i] = new int[sizes[size + i]]{ base[i] };
			bt[size + i] = BIT(sizes[size + i]);
		}
		for (int i = size - 1; i > 0; i--) {
			sizes[i] = sizes[2 * i] + sizes[2 * i + 1];
			data[i] = new int[sizes[i]];
			std::merge(data[2 * i], data[2 * i] + sizes[2 * i], data[2 * i + 1], data[2 * i + 1] + sizes[2 * i + 1], data[i]);
			bt[i] = BIT(sizes[i]);
		}
	}

	void ds(int i) {
		int val = data[i += size][0];
		for (; i > 0; i /= 2) {
			bt[i].update(std::lower_bound(data[i], data[i] + sizes[i], val) - data[i], -1);
		}
	}

	//[l, r)
	int getGt(int l, int r, int val) {
		int res = 0;
		l += size; r += size - 1;
		while (l < r) {
			if (l % 2) {
				res += gt(l++, val);
			}
			if (!(r % 2)) {
				res += gt(r--, val);
			}
			l /= 2;
			r /= 2;
		}
		if (l == r) {
			res += gt(l, val);
		}
		return res;
	}
	
	//[l, r)
	int getLs(int l, int r, int val) {
		int res = 0;
		l += size; r += size - 1;
		while (l < r) {
			if (l % 2) {
				res += ls(l++, val);
			}
			if (!(r % 2)) {
				res += ls(r--, val);
			}
			l /= 2;
			r /= 2;
		}
		if (l == r) {
			res += ls(l, val);
		}
		return res;
	}
};


int64_t get(int n, int *data) {
	BIT bt(n + 5, 0);
	int64_t res = 0;
	for (int i = n - 1; i >= 0; i--) {
		res += bt.get(data[i]);
		bt.update(data[i], 1);
	}
	return res;
}

int n, input[100005], pos[100005], q[100005];
int64_t ans;


int32_t main() {
	std::ios_base::sync_with_stdio(false);
	std::cin.tie(0);
	std::cout.tie(0);

	std::cin >> n;
	for (int i = 0; i < n; i++) {
		std::cin >> input[i];
		pos[input[i]] = i;
	}

	MST mst(n, input);
	ans = get(n, input);

	for (int i = 0; i < (n - 2); i++) {
		std::cin >> q[i];
	}

	std::cout << ans << ' ';
	for (int i = 0; i < (n - 2); i++) {
		int v = q[i];
		v = pos[v];

		ans -= mst.getGt(0, v, input[v]) + mst.getLs(v + 1, n, input[v]);
		mst.ds(v);
		std::cout << ans << " \n"[i == (n - 3)];
	}


	std::cout.flush();
	return 0;
}



/*
6
6 1 2 5 3 4
3 5 4 6

*/